@@ -39,8 +39,6 @@
 #include "properties_dialog.h"
 #include "menus.h"
 
-#include "icon.h"
-
 #define APP_SCITEPROJ_ERROR g_quark_from_static_string("APP_GUI_ERROR")
 
 
@@ -61,8 +59,8 @@ ClickedNode recent_clicked_node;
 /**
  * forward declarations
  */
-static gboolean recent_mouse_button_pressed_cb(GtkWidget *treeView, GdkEventButton *event, gpointer userData);
-static void recent_tree_row_activated_cb(GtkTreeView *treeView,
+static gboolean recent_mouse_button_pressed_cb (GtkWidget *treeView, GdkEventButton *event, gpointer userData);
+static void recent_tree_row_activated_cb (GtkTreeView *treeView,
         GtkTreePath *path,
         GtkTreeViewColumn *column,
         gpointer userData);
@@ -74,9 +72,9 @@ static void recent_tree_row_activated_cb(GtkTreeView *treeView,
  *
  * @param err returns any error information
  */
-GtkTreeStore* create_treestore_recent(GError **err)
+GtkTreeStore* create_treestore_recent (GError **err)
 {
-   GtkTreeStore *result = gtk_tree_store_new(COLUMN_EOL,
+   GtkTreeStore *result = gtk_tree_store_new (COLUMN_EOL,
                          TYPE_ITEMTYPE,
                          TYPE_FILEPATH,
                          TYPE_FILENAME,
@@ -85,11 +83,12 @@ GtkTreeStore* create_treestore_recent(GError **err)
                          TYPE_FONTWEIGHTSET,
                          TYPE_ICON,
                          TYPE_EXPANDED,
-                         TYPE_FOLDER_CONTENT_LOADED);
+                         TYPE_FOLDER_CONTENT_LOADED,
+                         TYPE_FOLDER_SORT_ORDER);
 
    if (result == NULL) {
-      g_set_error(err, APP_SCITEPROJ_ERROR, -1,
-                  "%s: %s, gtk_tree_store_new() = NULL",
+      g_set_error (err, APP_SCITEPROJ_ERROR, -1,
+                  "%s: %s, gtk_tree_store_new () = NULL",
                   __func__,
                   "Couldn't init treestore"
                  );
@@ -103,7 +102,7 @@ GtkTreeStore* create_treestore_recent(GError **err)
 /**
  *
  */
-GtkWidget *init_recent_files(GError **err)
+GtkWidget *init_recent_files (GError **err)
 {
 
    GtkCellRenderer *recentCellRenderer = NULL;
@@ -114,9 +113,9 @@ GtkWidget *init_recent_files(GError **err)
 
 
    // add a scrolledwindow for recent files
-   if (!(recentScrolledWindow = gtk_scrolled_window_new(NULL, NULL))) {
-      g_set_error(err, APP_SCITEPROJ_ERROR, -1,
-                  "%s: %s, gtk_scrolled_window_new() = NULL",
+   if (!(recentScrolledWindow = gtk_scrolled_window_new (NULL, NULL))) {
+      g_set_error (err, APP_SCITEPROJ_ERROR, -1,
+                  "%s: %s, gtk_scrolled_window_new () = NULL",
                   __func__,
                   "Couldn't init recent scrolled window"
                  );
@@ -124,14 +123,14 @@ GtkWidget *init_recent_files(GError **err)
       goto EXITPOINT;
    }
 
-   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(recentScrolledWindow),
-                                  GTK_POLICY_AUTOMATIC,
-                                  GTK_POLICY_ALWAYS);
+   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (recentScrolledWindow),
+                                   GTK_POLICY_AUTOMATIC,
+                                   GTK_POLICY_ALWAYS);
 
 
-   if ((recentTreeStore = create_treestore_recent(&tempErr)) == NULL) {
+   if ((recentTreeStore = create_treestore_recent (&tempErr)) == NULL) {
       if (tempErr) {
-         g_set_error(err, APP_SCITEPROJ_ERROR, -1 ,
+         g_set_error (err, APP_SCITEPROJ_ERROR, -1 ,
                      "%s: %s",
                      tempErr->message,
                      "Couldn't init recent treestore"
@@ -140,8 +139,8 @@ GtkWidget *init_recent_files(GError **err)
       goto EXITPOINT;
    }
 
-   if (!(recentTreeView = gtk_tree_view_new_with_model(GTK_TREE_MODEL(recentTreeStore)))) {
-      g_set_error(err, APP_SCITEPROJ_ERROR, -1,
+   if (!(recentTreeView = gtk_tree_view_new_with_model (GTK_TREE_MODEL(recentTreeStore)))) {
+      g_set_error (err, APP_SCITEPROJ_ERROR, -1,
                   "%s: %s, gtk_tree_view_new_with_model() = NULL",
                   __func__,
                   "Couldn't init recent gtk_tree_view"
@@ -150,12 +149,12 @@ GtkWidget *init_recent_files(GError **err)
       goto EXITPOINT;
    }
 
-   gtk_widget_show(recentScrolledWindow);
+   gtk_widget_show (recentScrolledWindow);
 
-   gtk_container_add(GTK_CONTAINER(recentScrolledWindow), recentTreeView);
+   gtk_container_add (GTK_CONTAINER(recentScrolledWindow), recentTreeView);
 
-   if (!(recentCellRenderer = gtk_cell_renderer_text_new())) {
-      g_set_error(err, APP_SCITEPROJ_ERROR, -1,
+   if (!(recentCellRenderer = gtk_cell_renderer_text_new ())) {
+      g_set_error (err, APP_SCITEPROJ_ERROR, -1,
                   "%s: %s, gtk_cell_renderer_text_new() = NULL",
                   __func__,
                   "Couldn't init recent gtk_cell_renderer"
@@ -164,8 +163,8 @@ GtkWidget *init_recent_files(GError **err)
       goto EXITPOINT;
    }
 
-   if (!(recentColumn1 = gtk_tree_view_column_new())) {
-      g_set_error(err, APP_SCITEPROJ_ERROR, -1,
+   if (!(recentColumn1 = gtk_tree_view_column_new ())) {
+      g_set_error (err, APP_SCITEPROJ_ERROR, -1,
                   "%s: %s, gtk_tree_view_column_new() = NULL",
                   __func__,
                   "Couldn't init recent gtk_tree_view_column"
@@ -174,10 +173,10 @@ GtkWidget *init_recent_files(GError **err)
       goto EXITPOINT;
    }
 
-   g_object_set(recentColumn1, "title", _("Recently opened files:"), NULL);
+   g_object_set (recentColumn1, "title", _("Recently opened files:"), NULL);
 
-   if (!(recentPixbuffCellRenderer = gtk_cell_renderer_pixbuf_new())) {
-      g_set_error(err, APP_SCITEPROJ_ERROR, -1,
+   if (!(recentPixbuffCellRenderer = gtk_cell_renderer_pixbuf_new ())) {
+      g_set_error (err, APP_SCITEPROJ_ERROR, -1,
                   "%s: %s, gtk_cell_renderer_pixbuf_new() = NULL",
                   __func__,
                   "Couldn't init recent gtk_cell_renderer_pixbuf"
@@ -187,29 +186,29 @@ GtkWidget *init_recent_files(GError **err)
    }
 
 
-   gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(recentTreeView), TRUE);
+   gtk_tree_view_set_headers_visible (GTK_TREE_VIEW(recentTreeView), TRUE);
 
-   gtk_tree_view_column_set_resizable(recentColumn1, TRUE);
-   gtk_tree_view_column_set_min_width(recentColumn1, (int)(prefs.width*.75));
+   gtk_tree_view_column_set_resizable (recentColumn1, TRUE);
+   gtk_tree_view_column_set_min_width (recentColumn1, (int)(prefs.width*.75));
 
 
-   gtk_tree_view_column_pack_start(recentColumn1, recentPixbuffCellRenderer , FALSE);
-   gtk_tree_view_column_add_attribute(recentColumn1, recentPixbuffCellRenderer , "pixbuf", COLUMN_ICON);
+   gtk_tree_view_column_pack_start (recentColumn1, recentPixbuffCellRenderer , FALSE);
+   gtk_tree_view_column_add_attribute (recentColumn1, recentPixbuffCellRenderer , "pixbuf", COLUMN_ICON);
 
 
-   gtk_tree_view_column_pack_start(recentColumn1, recentCellRenderer, TRUE);
-   gtk_tree_view_column_add_attribute(recentColumn1, recentCellRenderer, "text", COLUMN_FILENAME);
-   gtk_tree_view_column_add_attribute(recentColumn1, recentCellRenderer, "weight", COLUMN_FONTWEIGHT);
-   gtk_tree_view_column_add_attribute(recentColumn1, recentCellRenderer, "weight-set", COLUMN_FONTWEIGHTSET);
+   gtk_tree_view_column_pack_start (recentColumn1, recentCellRenderer, TRUE);
+   gtk_tree_view_column_add_attribute (recentColumn1, recentCellRenderer, "text", COLUMN_FILENAME);
+   gtk_tree_view_column_add_attribute (recentColumn1, recentCellRenderer, "weight", COLUMN_FONTWEIGHT);
+   gtk_tree_view_column_add_attribute (recentColumn1, recentCellRenderer, "weight-set", COLUMN_FONTWEIGHTSET);
 
 
-   g_signal_connect(G_OBJECT(recentTreeView), "button-press-event", G_CALLBACK(recent_mouse_button_pressed_cb), recentTreeView);
+   g_signal_connect (G_OBJECT (recentTreeView), "button-press-event", G_CALLBACK (recent_mouse_button_pressed_cb), recentTreeView);
 
-   g_signal_connect(G_OBJECT(recentTreeView), "row-activated", G_CALLBACK(recent_tree_row_activated_cb), NULL);
+   g_signal_connect (G_OBJECT (recentTreeView), "row-activated", G_CALLBACK (recent_tree_row_activated_cb), NULL);
 
-   gtk_tree_view_append_column(GTK_TREE_VIEW(recentTreeView), recentColumn1);
+   gtk_tree_view_append_column (GTK_TREE_VIEW (recentTreeView), recentColumn1);
 
-   gtk_widget_show(recentTreeView);
+   gtk_widget_show (recentTreeView);
 
 EXITPOINT:
 
@@ -220,20 +219,20 @@ EXITPOINT:
 /**
  * GtkTreeModelForeachFunc
  */
-gboolean tree_for_each(GtkTreeModel *model,GtkTreePath *path,GtkTreeIter *iter,gpointer data)
+gboolean tree_for_each (GtkTreeModel *model,GtkTreePath *path,GtkTreeIter *iter, gpointer data)
 {
 
    gchar *filepath, *filename;
    gchar *inFile = (gchar*)(data);
 
-   gtk_tree_model_get(model, iter, COLUMN_FILEPATH, &filename, -1);
+   gtk_tree_model_get (model, iter, COLUMN_FILEPATH, &filename, -1);
 
-   filepath = get_filename_from_full_path((gchar*)filename);
+   filepath = get_filename_from_full_path ((gchar*)filename);
 
-   if (g_strcmp0(filepath, inFile) == 0) {
+   if (g_strcmp0 (filepath, inFile) == 0) {
       //savedIter=iter;
 
-      gtk_tree_store_remove(recentTreeStore, iter);
+      gtk_tree_store_remove (recentTreeStore, iter);
       return TRUE;
    }
 
@@ -244,9 +243,9 @@ gboolean tree_for_each(GtkTreeModel *model,GtkTreePath *path,GtkTreeIter *iter,g
 /**
  *
  */
-void remove_if_already_exists(const gchar *filepath)
+void remove_if_already_exists (const gchar *filepath)
 {
-   gtk_tree_model_foreach(gtk_tree_view_get_model(GTK_TREE_VIEW(recentTreeView)), tree_for_each, (gpointer)(filepath));
+   gtk_tree_model_foreach (gtk_tree_view_get_model (GTK_TREE_VIEW (recentTreeView)), tree_for_each, (gpointer)(filepath));
 }
 
 
@@ -254,7 +253,7 @@ void remove_if_already_exists(const gchar *filepath)
  * add_file
  *	@returns TRUE if added the file successfully, FALSE otherwise
  */
-gboolean add_file_to_recent(gchar *filepath, GError **err)
+gboolean add_file_to_recent (gchar *filepath, GError **err)
 {
    g_assert(recentTreeStore != NULL);
    g_assert(filepath != NULL);
@@ -263,7 +262,7 @@ gboolean add_file_to_recent(gchar *filepath, GError **err)
    gboolean finalResult = FALSE;
    GtkTreeIter iter;
    const gchar* fileName = NULL;
-   gchar *fileExt = NULL;
+   // gchar *fileExt = NULL;
    gchar *relFilename = NULL; //g_strdup(filepath);
 
    /*
@@ -272,25 +271,25 @@ gboolean add_file_to_recent(gchar *filepath, GError **err)
    }
    else
       */
-   if (!abs_path_to_relative_path(filepath, &relFilename, get_project_directory(), err)) {
+   if (!abs_path_to_relative_path (filepath, &relFilename, get_project_directory(), err)) {
       printf("--- abs_path_to_relative_path FAILED!\n");
       goto EXITPOINT;
    }
 
 
    // Extract filename from filepath
-   fileName = get_filename_from_full_path((gchar*)filepath);
+   fileName = get_filename_from_full_path ((gchar*)filepath);
 
-   remove_if_already_exists(fileName);
+   remove_if_already_exists (fileName);
 
    // Append to root, or before/after/within an existing node?
 
    //if (currentIter == NULL) {
    if (!prefs.recent_add_to_bottom) {
-      gtk_tree_store_insert_after(recentTreeStore, &iter, NULL, NULL);
+      gtk_tree_store_insert_after (recentTreeStore, &iter, NULL, NULL);
    } else {
       // get the iter of the last item
-      gtk_tree_store_append(recentTreeStore, &iter, NULL);
+      gtk_tree_store_append (recentTreeStore, &iter, NULL);
    }
    //}
    /*
@@ -305,6 +304,7 @@ gboolean add_file_to_recent(gchar *filepath, GError **err)
    }
    */
 
+   /*
    fileExt = strrchr(fileName, '.');
 
    if (fileExt != NULL) {
@@ -314,24 +314,25 @@ gboolean add_file_to_recent(gchar *filepath, GError **err)
    if (fileExt == NULL || (int)strlen(fileExt) <= 0) {
       fileExt = (gchar*)fileName;
    }
+   */
 
 
-   gtk_tree_store_set(recentTreeStore, &iter, COLUMN_ITEMTYPE, ITEMTYPE_FILE, -1);
-   gtk_tree_store_set(recentTreeStore, &iter, COLUMN_FILEPATH, relFilename, -1);
-   gtk_tree_store_set(recentTreeStore, &iter, COLUMN_FILENAME, fileName, -1);
+   gtk_tree_store_set (recentTreeStore, &iter, COLUMN_ITEMTYPE, ITEMTYPE_FILE, -1);
+   gtk_tree_store_set (recentTreeStore, &iter, COLUMN_FILEPATH, relFilename, -1);
+   gtk_tree_store_set (recentTreeStore, &iter, COLUMN_FILENAME, fileName, -1);
 
-   gtk_tree_store_set(recentTreeStore, &iter, COLUMN_EXPANDED, FALSE, -1);
+   gtk_tree_store_set (recentTreeStore, &iter, COLUMN_EXPANDED, FALSE, -1);
 
 
-   GdkPixbuf *icon_pixbuf = get_pixbuf_from_filename((gchar*)(filepath), GTK_ICON_SIZE_MENU);
+   GdkPixbuf *icon_pixbuf = get_pixbuf_from_filename ((gchar*)(filepath), GTK_ICON_SIZE_MENU);
 
-   gtk_tree_store_set(recentTreeStore, &iter, COLUMN_ICON, icon_pixbuf, -1);
+   gtk_tree_store_set (recentTreeStore, &iter, COLUMN_ICON, icon_pixbuf, -1);
 
    finalResult = TRUE;
 
 EXITPOINT:
 
-   if (relFilename) g_free(relFilename);
+   if (relFilename) g_free (relFilename);
 
    return finalResult;
 }
@@ -345,7 +346,7 @@ EXITPOINT:
  * @param event is the GdkEventButton event object
  * @param userData is not currently used
  */
-static gboolean recent_mouse_button_pressed_cb(GtkWidget *treeView, GdkEventButton *event, gpointer userData)
+static gboolean recent_mouse_button_pressed_cb (GtkWidget *treeView, GdkEventButton *event, gpointer userData)
 {
    gboolean eventHandled = FALSE;
    GtkTreePath *path = NULL;
@@ -372,7 +373,7 @@ static gboolean recent_mouse_button_pressed_cb(GtkWidget *treeView, GdkEventButt
 
    // Find if the user has clicked on a node
 
-   if (!gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(treeView),
+   if (!gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (treeView),
                                       (gint) event->x,
                                       (gint) event->y,
                                       &path,
@@ -387,17 +388,17 @@ static gboolean recent_mouse_button_pressed_cb(GtkWidget *treeView, GdkEventButt
 
    // User clicked on a node, so retrieve the particulars
 
-   treeModel = gtk_tree_view_get_model(GTK_TREE_VIEW(treeView));
+   treeModel = gtk_tree_view_get_model (GTK_TREE_VIEW(treeView));
 
-   if (!gtk_tree_model_get_iter(treeModel, &iter, path)) {
+   if (!gtk_tree_model_get_iter (treeModel, &iter, path)) {
       goto EXITPOINT;
    }
 
-   gtk_tree_model_get(treeModel, &iter, COLUMN_ITEMTYPE, &nodeItemType, COLUMN_FILEPATH, &nodeName, -1);
+   gtk_tree_model_get (treeModel, &iter, COLUMN_ITEMTYPE, &nodeItemType, COLUMN_FILEPATH, &nodeName, -1);
 
    // Save the node info for use by the popup menu callbacks
 
-   if (recent_clicked_node.name) g_free(recent_clicked_node.name);
+   if (recent_clicked_node.name) g_free (recent_clicked_node.name);
 
    recent_clicked_node.valid = TRUE;
    recent_clicked_node.iter = iter;
@@ -406,17 +407,17 @@ static gboolean recent_mouse_button_pressed_cb(GtkWidget *treeView, GdkEventButt
    nodeName = NULL;
 
    // Check if something is selected
-   tree_selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeView));
+   tree_selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeView));
 
    if (tree_selection != NULL) {
       // Check if clicked on something in the selection, otherwise make the clicked one the selection.
 
-      if (gtk_tree_selection_path_is_selected(tree_selection, path) == FALSE) {
+      if (gtk_tree_selection_path_is_selected (tree_selection, path) == FALSE) {
          // clear selection and make current line selected
 
-         gtk_tree_selection_unselect_all(tree_selection);
+         gtk_tree_selection_unselect_all (tree_selection);
 
-         gtk_tree_selection_select_path(tree_selection, path);
+         gtk_tree_selection_select_path (tree_selection, path);
       }
    }
 
@@ -424,7 +425,7 @@ static gboolean recent_mouse_button_pressed_cb(GtkWidget *treeView, GdkEventButt
 
    //if (nodeItemType == ITEMTYPE_FILE) {
    if (recentPopupMenu) {
-      gtk_menu_popup_at_pointer(GTK_MENU(recentPopupMenu), (GdkEvent*)event);
+      gtk_menu_popup_at_pointer (GTK_MENU (recentPopupMenu), (GdkEvent*)event);
    }
    /*
    }
@@ -440,8 +441,8 @@ static gboolean recent_mouse_button_pressed_cb(GtkWidget *treeView, GdkEventButt
 
 EXITPOINT:
 
-   if (path) gtk_tree_path_free(path);
-   if (nodeName) g_free(nodeName);
+   if (path) gtk_tree_path_free (path);
+   if (nodeName) g_free (nodeName);
 
    return eventHandled;
 }
@@ -451,7 +452,7 @@ EXITPOINT:
  * Open the selected file.
  *	This is called when a file is rightclicked and open is selected in the menu
  */
-void popup_open_recent_file_cb()
+void popup_open_recent_file_cb ()
 {
    gchar *command = NULL;
    GError *err = NULL;
@@ -466,7 +467,7 @@ void popup_open_recent_file_cb()
 
    //debug_printf("name:%s\n",recent_clicked_node.name);
 
-   if (!open_filename(recent_clicked_node.name, (gchar*)get_project_directory(), &err)) {
+   if (!open_filename (recent_clicked_node.name, (gchar*)get_project_directory (), &err)) {
       goto EXITPOINT;
    }
 
@@ -474,20 +475,20 @@ void popup_open_recent_file_cb()
 EXITPOINT:
 
    if (err != NULL) {
-      dialog = gtk_message_dialog_new(NULL,
-                                      GTK_DIALOG_MODAL,
-                                      GTK_MESSAGE_ERROR,
-                                      GTK_BUTTONS_OK,
-                                      "Could not open selected file: \n\n%s",
-                                      err->message);
+      dialog = gtk_message_dialog_new (NULL,
+                                       GTK_DIALOG_MODAL,
+                                       GTK_MESSAGE_ERROR,
+                                       GTK_BUTTONS_OK,
+                                       "Could not open selected file: \n\n%s",
+                                       err->message);
 
-      gtk_dialog_run(GTK_DIALOG (dialog));
+      gtk_dialog_run (GTK_DIALOG (dialog));
    }
 
-   if (command) g_free(command);
-   if (absFilePath) g_free(absFilePath);
-   if (err) g_error_free(err);
-   if (dialog) gtk_widget_destroy(dialog);
+   if (command) g_free (command);
+   if (absFilePath) g_free (absFilePath);
+   if (err) g_error_free (err);
+   if (dialog) gtk_widget_destroy (dialog);
 }
 
 
@@ -500,7 +501,7 @@ EXITPOINT:
  * @param column is not used
  * @param userData is not used
  */
-static void recent_tree_row_activated_cb(GtkTreeView *treeView,
+static void recent_tree_row_activated_cb (GtkTreeView *treeView,
         GtkTreePath *path,
         GtkTreeViewColumn *column,
         gpointer userData)
@@ -515,66 +516,66 @@ static void recent_tree_row_activated_cb(GtkTreeView *treeView,
 
    // Get the data from the row that was activated
 
-   GtkTreeModel *treeModel = gtk_tree_view_get_model(treeView);
-   gtk_tree_model_get_iter(treeModel, &iter, path);
-   gtk_tree_model_get(treeModel, &iter, COLUMN_ITEMTYPE, &nodeItemType, COLUMN_FILEPATH, &relFilePath, -1);
+   GtkTreeModel *treeModel = gtk_tree_view_get_model (treeView);
+   gtk_tree_model_get_iter (treeModel, &iter, path);
+   gtk_tree_model_get (treeModel, &iter, COLUMN_ITEMTYPE, &nodeItemType, COLUMN_FILEPATH, &relFilePath, -1);
 
-   gchar *absFilePath = fix_path((gchar*)get_project_directory(),relFilePath);
+   gchar *absFilePath = fix_path ((gchar*)get_project_directory (),relFilePath);
 
-   gchar *fixed = fix_path((gchar*)get_project_directory(),relFilePath);
+   gchar *fixed = fix_path ((gchar*)get_project_directory (),relFilePath);
 
-   if ((command = g_strdup_printf("open:%s\n", fixed)) == NULL) {
-      g_set_error(&err, APP_SCITEPROJ_ERROR, -1,
+   if ((command = g_strdup_printf ("open:%s\n", fixed)) == NULL) {
+      g_set_error (&err, APP_SCITEPROJ_ERROR, -1,
                   "%s: %s, g_strdup_printf() = NULL",
                   __func__,
                   "Error formatting SciTE command"
                  );
    }
    else {
-      if (send_scite_command(command, &err)) {
+      if (send_scite_command (command, &err)) {
          // Try to activate SciTE; ignore errors
 
-         activate_scite(NULL);
+         activate_scite (NULL);
 
          if (prefs.give_scite_focus == TRUE) {
-            send_scite_command((gchar*)"focus:0", NULL);
+            send_scite_command ((gchar*)"focus:0", NULL);
          }
 
-         add_file_to_recent(fixed, NULL);
+         add_file_to_recent (fixed, NULL);
 
-         gchar *statusbar_text = g_strdup_printf(_("Opened %s"),
-                                               remove_newline(get_filename_from_full_path(command)));
+         gchar *statusbar_text = g_strdup_printf (_("Opened %s"),
+                                               remove_newline (get_filename_from_full_path (command)));
 
-         set_statusbar_text(statusbar_text);
+         set_statusbar_text (statusbar_text);
 
-         g_free(statusbar_text);
+         g_free (statusbar_text);
       }
    }
 
 //EXITPOINT:
 
    if (err != NULL) {
-      dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-                                      _("Could not open selected file: \n\n%s"),
-                                      err->message
-                                     );
+      dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
+                                       _("Could not open selected file: \n\n%s"),
+                                       err->message
+                                      );
 
-      gtk_dialog_run(GTK_DIALOG (dialog));
+      gtk_dialog_run (GTK_DIALOG (dialog));
    }
 
-   if (relFilePath) g_free(relFilePath);
-   if (absFilePath) g_free(absFilePath);
-   if (command) g_free(command);
-   if (err) g_error_free(err);
-   if (dialog) gtk_widget_destroy(dialog);
-   if (fixed) g_free(fixed);
+   if (relFilePath) g_free (relFilePath);
+   if (absFilePath) g_free (absFilePath);
+   if (command) g_free (command);
+   if (err) g_error_free (err);
+   if (dialog) gtk_widget_destroy (dialog);
+   if (fixed) g_free (fixed);
 }
 
 
 /**
  *
  */
-void popup_remove_recent_file_cb()
+void popup_remove_recent_file_cb ()
 {
    gchar *command = NULL;
    GError *err = NULL;
@@ -588,25 +589,25 @@ void popup_remove_recent_file_cb()
       goto EXITPOINT;
    }
 
-   fileName = get_filename_from_full_path((gchar*)recent_clicked_node.name);
+   fileName = get_filename_from_full_path ((gchar*)recent_clicked_node.name);
 
-   remove_if_already_exists(fileName);
+   remove_if_already_exists (fileName);
 
 EXITPOINT:
 
    if (err != NULL) {
-      dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-                                      _("Could not open selected file: \n\n%s"),
-                                      err->message
-                                     );
+      dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
+                                       _("Could not open selected file: \n\n%s"),
+                                       err->message
+                                       );
 
-      gtk_dialog_run(GTK_DIALOG (dialog));
+      gtk_dialog_run (GTK_DIALOG (dialog));
    }
 
-   if (command) g_free(command);
-   if (absFilePath) g_free(absFilePath);
-   if (err) g_error_free(err);
-   if (dialog) gtk_widget_destroy(dialog);
+   if (command) g_free (command);
+   if (absFilePath) g_free (absFilePath);
+   if (err) g_error_free (err);
+   if (dialog) gtk_widget_destroy (dialog);
 
 }
 
@@ -614,12 +615,12 @@ EXITPOINT:
 /**
  * Callback for the menu item
  */
-void copy_recent_filename_to_clipboard_cb()
+void copy_recent_filename_to_clipboard_cb ()
 {
    if (!recent_clicked_node.valid || recent_clicked_node.type != ITEMTYPE_FILE) {
       //goto EXITPOINT;
    } else {
-      copy_filename_to_clipboard(gtk_tree_view_get_model(GTK_TREE_VIEW(recentTreeView)), &(recent_clicked_node.iter));
+      copy_filename_to_clipboard (gtk_tree_view_get_model (GTK_TREE_VIEW (recentTreeView)), &(recent_clicked_node.iter));
 
    }
 }
@@ -628,12 +629,12 @@ void copy_recent_filename_to_clipboard_cb()
 /**
  *
  */
-void properties_recent_file_cb()
+void properties_recent_file_cb ()
 {
    if (!recent_clicked_node.valid || recent_clicked_node.type != ITEMTYPE_FILE) {
       //goto EXITPOINT;
    } else {
-      file_properties_gui(gtk_tree_view_get_model(GTK_TREE_VIEW(recentTreeView)), &(recent_clicked_node.iter));
+      file_properties_gui (gtk_tree_view_get_model (GTK_TREE_VIEW (recentTreeView)), &(recent_clicked_node.iter));
 
    }
 }
