@@ -1,7 +1,7 @@
 /**
  * tree_manipulation.h - GtkTreeView manipulation code for SciteProj
  *
- *  Copyright 2006 Roy Wood, 2009-2017 Andreas Rönnquist
+ *  Copyright 2006 Roy Wood, 2009-2023 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  *
@@ -16,8 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with SciteProj.
- * If not, see <http://www.gnu.org/licenses/>.
+ * along with SciteProj.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 #ifndef __HEADER_TREE_MANIPULATION_
@@ -45,6 +44,7 @@ enum {
    COLUMN_ICON,
    COLUMN_EXPANDED,
    COLUMN_FOLDER_CONTENT_LOADED,
+   COLUMN_FOLDER_SORT_ORDER,
    COLUMN_EOL
 };
 
@@ -70,65 +70,77 @@ enum {
 #define TYPE_ICON                    GDK_TYPE_PIXBUF
 #define TYPE_EXPANDED                G_TYPE_BOOLEAN
 #define TYPE_FOLDER_CONTENT_LOADED   G_TYPE_BOOLEAN
+#define TYPE_FOLDER_SORT_ORDER       G_TYPE_INT
 
 
 
-typedef gint(*StringCompareFunction)(gconstpointer,gconstpointer);
+typedef gint(*StringCompareFunction) (gconstpointer,gconstpointer);
 
 
 // Set the Project filepath
-gboolean set_project_filepath(const gchar *filepath, GError **err);
+gboolean set_project_filepath (const gchar *filepath, GError **err);
 
 // Get the GTKTreeStore
-GtkTreeStore* create_treestore(GError **err);
+GtkTreeStore* create_treestore (GError **err);
+
+void done_treestore();
 
 // Get the project file directory
-const gchar* get_project_directory();
-gchar* get_project_filepath();
+const gchar* get_project_directory ();
+
+gboolean tree_iter_is_valid (GtkTreeIter *iter);
 
 // Allow user to select and add files to the project
-gboolean add_files_to_project(GtkTreeIter *parentIter, GError **err);
+gboolean add_files_to_project (GtkTreeIter *parentIter, GError **err);
 
 // Add a file node to a GtkTreeModel
-gboolean add_tree_file(GtkTreeIter *currentIter,
-                       enum NodePosition position,
-                       const gchar* filepath,
-                       GtkTreeIter *newIter,
-                       gboolean makeRelative,
-                       GError **err);
+gboolean add_tree_file (GtkTreeIter *currentIter,
+                        enum NodePosition position,
+                        const gchar* filepath,
+                        GtkTreeIter *newIter,
+                        gboolean makeRelative,
+                        GError **err);
 
 //gboolean add_tree_filelist(GtkTreeIter *parentIter, GSList *fileList, GError **err);
-gboolean add_tree_filelist(GtkTreeIter *parentIter, GSList *fileList, GError **err);
+gboolean add_tree_filelist (GtkTreeIter *parentIter, GSList *fileList, GError **err);
 
 // Add a group node to a GtkTreeModel
-gboolean add_tree_group(GtkTreeIter *parentIter,
-                        enum NodePosition position,
-                        const gchar* groupname,
-                        const gchar* full_name,
-                        gboolean expanded,
-                        GtkTreeIter *newIter,
-                        GError **err);
+gboolean add_tree_group (GtkTreeIter *parentIter,
+                         enum NodePosition position,
+                         const gchar* groupname,
+                         const gchar* full_name,
+                         gboolean expanded,
+                         GtkTreeIter *newIter,
+                         GError **err);
 
 // Remove a node from a GtkTreeModel
-gboolean remove_tree_node(GtkTreeIter *iter, GError **err);
+gboolean remove_tree_node (GtkTreeIter *iter, GError **err);
 
-gboolean set_tree_node_expanded(GtkTreeIter *iter, gboolean expanded, GError **err);
+gboolean set_tree_node_expanded (GtkTreeIter *iter, gboolean expanded, GError **err);
 
-gboolean set_tree_node_icon(GtkTreeIter *iter, GdkPixbuf *pixbuf, GError **err);
+gboolean set_tree_node_icon (GtkTreeIter *iter, GdkPixbuf *pixbuf, GError **err);
 
-gboolean set_tree_node_loaded(GtkTreeIter *iter, gboolean loaded, GError **err);
+gboolean set_tree_node_loaded (GtkTreeIter *iter, gboolean loaded, GError **err);
+
+gboolean set_tree_node_sort_order (GtkTreeIter *iter, gint sort_order, GError **err);
 
 // Copy a node in the tree (including children)
-gboolean copy_tree_node(GtkTreeIter *srcIter,
-                        GtkTreeIter *dstIter,
-                        enum NodePosition position,
-                        GtkTreeIter *newIter,
-                        GError **err);
+gboolean copy_tree_node (GtkTreeIter *srcIter,
+                         GtkTreeIter *dstIter,
+                         enum NodePosition position,
+                         GtkTreeIter *newIter,
+                         GError **err);
 
-gchar *get_path_string(GtkTreeIter *iter);
+gchar *get_path_string (GtkTreeIter *iter);
 
-void sort_children(GtkTreeIter *node,GError **err,StringCompareFunction compare_func);
+void sort_children (GtkTreeIter *node, GError **err, StringCompareFunction compare_func);
 
-gboolean add_tree_folderlist(GtkTreeIter *iter, GSList *folder_list, gchar *folder_path);
+gboolean add_tree_folderlist (GtkTreeIter *iter, GSList *folder_list, gchar *folder_path);
+
+GtkTreeIter *find_element_with_path (GtkTreeIter *start_iter, gchar *path_to_find);
+
+#ifdef _DEBUG
+void print_node (GtkTreeIter *iter);
+#endif
 
 #endif /*__HEADER_TREE_MANIPULATION_*/
